# ModelNewRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**owner_slug** | **str** | The owner&#39;s slug | 
**slug** | **str** | The slug that the model should be created with | 
**title** | **str** | The title of the new model | 
**subtitle** | **str** | The subtitle of the new model | [optional] 
**is_private** | **bool** | Whether or not the model should be private | [default to True]
**description** | **str** | The description to be set on the model | [optional] [default to '']
**publish_time** | **date** | When the model was initially published | [optional] 
**provenance_sources** | **str** | The provenance sources to be set on the model | [optional] [default to '']

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


